@@ -9,6 +9,16 @@ import requests as r
 
 class ApiResponse:
     """Class for data response of API resource call.
+
+    Keyword Args:
+        response (Union[None, Dict[str, List[Any]]], optional): complete response from api call as dict. Defaults to None.
+        data (Union[None, List[Any]], optional): only data from response from api call as list. Defaults to None.
+        skip (Union[None, int], optional): value of skipped pages. Defaults to None.
+        count (Union[None, int], optional): value of count. Defaults to None.
+        limit (Union[None, int], optional): value of limit. Defaults to None.
+        info (Union[None, Dict[str, str]], optional): value of info. Defaults to None.
+        provider (Union[None, str], optional): value of data provider. Defaults to None.
+
     """
 
     def __init__(
@@ -21,17 +31,6 @@ class ApiResponse:
         info=None,
         provider=None,
     ) -> None:
-        """Initialize instance of the class with provided attributes' values.
-
-        Args:
-            response (Union[None, Dict[str, List[Any]]], optional): complete response from api call as dict. Defaults to None.
-            data (Union[None, List[Any]], optional): only data from response from api call as list. Defaults to None.
-            skip (Union[None, int], optional): value of skipped pages. Defaults to None.
-            count (Union[None, int], optional): value of count. Defaults to None.
-            limit (Union[None, int], optional): value of limit. Defaults to None.
-            info (Union[None, Dict[str, str]], optional): value of info. Defaults to None.
-            provider (Union[None, str], optional): value of data provider. Defaults to None.
-        """
         self.response: Union[None, Dict[str, List[Any]]] = response
         self.data: Union[None, List[Any]] = data
         self.skip: Union[None, int] = skip
@@ -43,20 +42,19 @@ class ApiResponse:
 
 class ApiError:
     """Class for data response error return of API resource call.
-    """
 
-    def __init__(
-        self, response=None, error=None, status_code=None, name=None, message=None
-    ) -> None:
-        """Initialize instance of the class with provided attributes' values.
-
-        Args:
+        Keyword Args:
             response (Union[None, Dict[str, Dict[str, Any]]], optional): complete response message as dict. Defaults to None.
             error (Union[None, Dict[str, Any]], optional): error part of the respone message as dict. Defaults to None.
             status_code (Union[None, int], optional): status code part of the response message. Defaults to None.
             name (Union[None, str], optional): name of the error message. Defaults to None.
             message (Union[None, str], optional): body of the error message. Defaults to None.
-        """
+
+    """
+
+    def __init__(
+        self, response=None, error=None, status_code=None, name=None, message=None
+    ) -> None:
         self.response: Union[None, Dict[str, Dict[str, Any]]] = response
         self.error: Union[None, Dict[str, Any]] = error
         self.status_code: Union[None, int] = status_code
@@ -67,8 +65,6 @@ class ApiError:
 class API(r.Session):
     """API class for connection and getting data from Apitalks API resources.
 
-    Args:
-        r (r.Session): inheriting requests.Session class methods
     """
 
     base_url = "https://api.apitalks.store"
@@ -80,6 +76,7 @@ class API(r.Session):
 
         Args:
             api_key (str): api key. You need to register to Apitalks (free) to get it
+
         """
         super().__init__()
         self.api_auth_name = "x-api-key"
@@ -88,31 +85,28 @@ class API(r.Session):
     def query(
         self, resource: str, order=None, where=None, **kwargs
     ) -> Union[ApiResponse, ApiError, int]:
-        """Queries API for data from <resource>.
+        """Queries API for data from <resource>. See https://www.api.store/czso.cz/dokumentace#section/Query-parametry
 
         Args:
             resource (str): API resource path as specified in Apitalks documentation
 
-        Kwargs:
-            order (str): order output of returned data of api call. Argument has to adhere to formatting standard
-                as specified in Apitalks documentation.
-                e.g `order='"id ASC, nazev DESC"'`. See https://www.api.store/czso.cz/dokumentace#section/Query-parametry
+        Keyword Args:
+            order (str): order output of returned data of api call.
+                e.g `order='"id ASC, nazev DESC"'`. 
 
-            where (str): specifiy filtering of the returned data of api call. Argument has to adhere to formatting standard
-                as specified in Apitalks documentation.
-                e.g. `where='"rok":{"gt":2000}'` or `where='"rok=2000,"barva":"red"'
+            where (str): specifiy filtering of the returned data of api call.
+                e.g. `where='"rok":{"gt":2000}'` or `where='"rok=2000,"barva":"red"'`
 
             limit (int): add limit to set limit for one page of returned data via api call. 
-                See: https://www.api.store/czso.cz/dokumentace#section/Query-parametry
 
-            skip (int): add skip to set number of skipped pages via api call. Value should be same, as for argument <limit>.
-                See https://www.api.store/czso.cz/dokumentace#section/Query-parametry
+            skip (int): add skip to set number of skipped data entries via api call.
             
         Returns:
             (Union[ApiResponse, ApiError, int])
                 ApiResponse: class instance with attributes of successfull API call
                 ApiError: class instance with attributes of unsuccessfull API call
                 int: 1, if some other bad stuff happened
+
         """
         keys_ = list(kwargs.keys())
         retries = kwargs["retries"] if "retries" in keys_ else 0
@@ -138,6 +132,7 @@ class API(r.Session):
             params={"filter": filter_},
         )
         _json = _response.json()
+        _keys = list(_json.keys())
         print(f"Requested API resource: '{unquote_plus(_response.request.url)}'")  # type: ignore
 
         if _response.status_code in [200]:
@@ -145,29 +140,29 @@ class API(r.Session):
 
             return ApiResponse(
                 response=_json,
-                data=_json["data"],
-                skip=_json["skip"],
-                count=_json["count"],
-                limit=_json["limit"],
-                info=_json["info"],
-                provider=_json["info"]["provider"],
+                data=_json["data"] if "data" in _keys else None,
+                skip=_json["skip"] if "skip" in _keys else None,
+                count=_json["count"] if "count" in _keys else None,
+                limit=_json["limit"] if "limit" in _keys else None,
+                info=_json["info"] if "info" in _keys else None,
+                provider=_json["info"]["provider"] if "info" in _keys else None,
             )
 
         if _response.status_code in [400, 403, 404, 409, 429]:
             print(
-                f"API returned error. HTTP response status: {_response.status_code}. Returned message: {_json['error']['message']}."
+                f"API returned error. HTTP response status: {_response.status_code}. Returned message: {_json}."
             )
             return ApiError(
                 response=_json,
-                error=_json["error"],
-                status_code=_json["error"]["statusCode"],
-                name=_json["error"]["name"],
-                message=_json["error"]["message"],
+                error=_json["error"] if "error" in _keys else None,
+                status_code=_json["error"]["statusCode"] if "error" in _keys else None,
+                name=_json["error"]["name"] if "error" in _keys else None,
+                message=_json["error"]["message"] if "error" in _keys else None,
             )
 
         if _response.status_code in [502, 503, 504]:
             print(
-                f"API returned error. HTTP response status: {_response.status_code}. Returned message: {_json['error']['message']}. Retrying..."
+                f"API returned error. HTTP response status: {_response.status_code}. Returned message: {_json}. Retrying..."
             )
             if retries <= 10:
                 sleep(retries * 2)
@@ -184,10 +179,10 @@ class API(r.Session):
             print(f"Retried {retries} times. That is enough.")
             return ApiError(
                 response=_json,
-                error=_json["error"],
-                status_code=_json["error"]["statusCode"],
-                name=_json["error"]["name"],
-                message=_json["error"]["message"],
+                error=_json["error"] if "error" in _keys else None,
+                status_code=_json["error"]["statusCode"] if "error" in _keys else None,
+                name=_json["error"]["name"] if "error" in _keys else None,
+                message=_json["error"]["message"] if "error" in _keys else None,
             )
 
         return 1
